==> MuSE-0.7.2.tar.gz: MuSE-0.7.2/gtkgui/about.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>
#include <string.h>
#include <gtk/gtk.h>
#include "gchan.h"
#include "about.h"
#include <config.h>

GtkWidget *winabout;

void aboutwin(GtkWidget *w)
{
	char abouttext[4096];
	char title[500];
	GtkWidget *text, *scrollbar, *verbox, *tmpwid;

	if(winabout)
		return;

	/*FIXME: set versions*/
	snprintf(abouttext, sizeof(abouttext), 
			
"           d y n e . o r g productions proudly presents:

		
MuSE <------- http://muse.dyne.org --------------> Multiple Streaming Engine 


MuSE is an application for the mixing, encoding, and streaming of sound:
is an engine that can simultaniously mix up to 6 separate MP3 or OggVorbis
audio files from the hard drive or the network, where each channel of audio
can be dynamicly adjusted for speed and volume plus a soundcard line-in
channel. The resulting stream can be played locally on the sound card and/
or encoded as an mp3 network stream to an icecast or shoutcast server (ready
to be mixed and played again by other muses... ;)


   the actual MuSE development team is composed by:
   ------------------------------------------------

 = Denis Rojo aka jaromil <jaromil@dyne.org>
   MuSE coder and mantainer

 = nightolo <night@autistici.org>
   GTK+ graphical interface coder ( /gtkgui )

 = Luca Profico aka rubik <rubik@olografix.org>
   NCURSES console interface coder ( /ncursesgui )

 = Matteo Nastasi aka MatOfPenguins <matteo.nastasi@milug.org>
   DSP, internal audio processing ( audioproc.cpp )


 if you wish to collaborate, join us on irc.openprojects.net #muse


MuSE as it is now would have never existed without the contributions of:
= Markus Seidl ( funda.ment.org ) for the idea of mixing and streaming multiple files
= August Black ( aug.ment.org ) for the original graphical user interface
= SERVUS.AT for trusting this project since the beginning and supporting it
= PUBLIC VOICE Lab ( pvl.at ) for recently giving MuSE support and new horizons of use
= Asbesto Molesto ( freaknet.org ) for the extensive testing and documentation
= Alex, Rasty and Martinez ( ! ) for the good karma


also waves and thanks to:
lobo, voyager, void, blicero, \\sANDMAN\\, the Freaknet Medialab,
the ASCII squat, henk, the imc-audio collective, jeff, the LOA hacklab,
the TPO, bundes & didi, indymedia italy, neural.it, the autistici.org
collective, Mag-One, radio onda rossa, bomboclat, c1cc10, vanguardist,
janki, godog and all the others i'm forgetting here!

	
MuSE redistributes, linking statically, the following libraries:
= libmpeg by Woo-jae Jung (now mantained by Mikael Hedin)
= libshout by Jack Moffit, Chad Armstrong and Scott Manley
= libcdk by Mike Glover


MuSE can link dinamically to the following libraries:
= libogg, libvorbis, libvorbisfile - www.xiph.org
= glib, libgdk, libgtk - www.gtk.org
= liblame - www.mp3dev.org/mp3
= libX11, libXext - www.xfree86.org
= other common GNU libraries


MuSE sourcecode also got inspirations and code snippets from the stream mixer
sourcecode by Scott Manley, the buffered FIFO pipe source by Charles Samuels,
the GTK knob widget by Alexander Koenig, GNOME icons by Jakub Steiner



MuSE is copyright (c) 2000, 2001, 2002 by Denis Rojo aka jaromil
MuSE's GTK+ GUI is copyright (c) 2001, 2002 by nightolo
MuSE's NCURSES GUI is copyright (c) 2002 by Luca Profico aka rubik
part of the included code is copyright by the respective authors,
please refer to the supplied sourcecode for further informations.


---------------------------------------------------------------


This source code is free software; you can redistribute it and/or
modify it under the terms of the GNU Public License as published 
by the Free Software Foundation; either version 2 of the License,
or (at your option) any later version.

This source code is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
Please refer to the GNU Public License for more details.

You should have received a copy of the GNU Public License along with
this source code; if not, write to:
Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.");
	
	snprintf(title, sizeof(title), "%s version %s - gtk+ version %u.%u.%u",
		 PACKAGE, VERSION, GTK_MAJOR_VERSION, GTK_MINOR_VERSION,
		 GTK_MICRO_VERSION);
	winabout=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(winabout), title);
	gtk_signal_connect(GTK_OBJECT(winabout), "delete_event",
			(GtkSignalFunc) about_close, winabout);
	gtk_container_set_border_width(GTK_CONTAINER(winabout), 7);
	
	verbox=gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(winabout), verbox);
	tmpwid=gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, FALSE, FALSE, 0);
	
	text=gtk_text_new(NULL, NULL);
	gtk_text_set_editable(GTK_TEXT(text), FALSE);
	gtk_widget_set_usize(text, 520, 400);
	gtk_box_pack_start(GTK_BOX(tmpwid), text, FALSE, FALSE, 0);

	scrollbar=gtk_vscrollbar_new(GTK_TEXT(text)->vadj);
	gtk_box_pack_start(GTK_BOX(tmpwid), scrollbar, FALSE, FALSE, 0);
	
	gtk_widget_realize(text);
	gtk_text_freeze(GTK_TEXT(text));
	gtk_text_insert(GTK_TEXT(text), NULL, &text->style->black , NULL,
			abouttext, strlen(abouttext));
	gtk_text_thaw(GTK_TEXT(text));
	
	tmpwid=gtk_hseparator_new();
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, TRUE, TRUE, 0);
	
	tmpwid=gtk_button_new_with_label("Close");
	gtk_signal_connect_object(GTK_OBJECT(tmpwid), "clicked",
			(GtkSignalFunc) about_close, GTK_OBJECT(winabout));
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, FALSE, FALSE, 0);
	
	gtk_widget_show_all(winabout);

}

void about_close(GtkWidget *w)
{
	gtk_widget_destroy(w);
	winabout=NULL;
}

==> MuSE-0.8.tar.gz: MuSE-0.8/gtkgui/about.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>
#include <string.h>
#include <gtk/gtk.h>
#include "gchan.h"
#include "about.h"
#include <config.h>


void aboutwin(GtkWidget *w)
{
	GtkWidget *winabout;
	char abouttext[4096];
	char title[500];
	GtkWidget *text, *scrollbar, *verbox, *tmpwid;

	/*FIXME: set versions*/
	snprintf(abouttext, sizeof(abouttext), 
"           d y n e . o r g productions proudly presents:

		
MuSE <------- http://muse.dyne.org --------------> Multiple Streaming Engine 


MuSE is an application for the mixing, encoding, and streaming of sound:
is an engine that can simultaniously mix up to 6 separate MP3 or OggVorbis
audio files from the hard drive or the network, where each channel of audio
can be dynamicly adjusted for speed and volume plus a soundcard line-in
channel. The resulting stream can be played locally on the sound card and/
or encoded as an mp3 network stream to an icecast or shoutcast server (ready
to be mixed and played again by other muses... ;)


   the actual MuSE development team is composed by:
   ------------------------------------------------

 = Denis Rojo aka jaromil <jaromil@dyne.org>
   MuSE coder and mantainer

 = nightolo <night@autistici.org>
   GTK+ graphical interface coder ( /gtkgui )

 = Luca Profico aka rubik <rubik@olografix.org>
   NCURSES console interface coder ( /ncursesgui )

 = Matteo Nastasi aka MatOfPenguins <matteo.nastasi@milug.org>
   DSP, internal audio processing ( audioproc.cpp )


 if you wish to collaborate, join us on irc.openprojects.net #muse


MuSE as it is now would have never existed without the contributions of:
= Markus Seidl ( funda.ment.org ) for the initial idea and need of MuSE
= August Black ( aug.ment.org ) for the first graphical user interface
= SERVUS.AT for trusting this project since the beginning and supporting it
= PUBLIC VOICE Lab ( pvl.at ) for support in MuSE 0.7 development
= Asbesto Molesto ( freaknet.org ) for the testing and documentation
= Alex, Rasty and Martinez ( ! ) for the good karma
= sandolo and godog for testing and debianization

also waves and thanks for this release go to:
gnumark, lobo, voyager, void, blicero, the Freaknet Medialab, the ASCII squat,
the LOA hacklab, the TPO, Boncinet, bundes & didi, indymedia italy, neural.it,
autistici.org/inventati.org, mag-one, radio ondarossa, bomboclat, c1cc10, the
OSSA crews and all the others i'm forgetting here!

	
MuSE redistributes, linking statically, the following libraries:
= libmpeg by Woo-jae Jung (now mantained by Mikael Hedin)
= libshout by Jack Moffit, Chad Armstrong and Scott Manley
= libcdk by Mike Glover


MuSE can link dinamically to the following libraries:
= libogg, libvorbis, libvorbisfile - www.xiph.org
= glib, libgdk, libgtk - www.gtk.org
= liblame - www.mp3dev.org/mp3
= libX11, libXext - www.xfree86.org
= other common GNU libraries


MuSE sourcecode also got inspirations and code snippets from the stream mixer
sourcecode by Scott Manley, the buffered FIFO pipe source by Charles Samuels,
the GTK knob widget by Alexander Koenig, GNOME icons by Jakub Steiner



MuSE is copyright (c) 2000 - 2003 by jaromil aka Denis Rojo
part of the included code is copyright by the respective authors,
please refer to the supplied sourcecode for further informations.


---------------------------------------------------------------


This source code is free software; you can redistribute it and/or
modify it under the terms of the GNU Public License as published 
by the Free Software Foundation; either version 2 of the License,
or (at your option) any later version.

This source code is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
Please refer to the GNU Public License for more details.

You should have received a copy of the GNU Public License along with
this source code; if not, write to:
Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.");
	
	snprintf(title, sizeof(title), "%s version %s - gtk+ version %u.%u.%u",
		 PACKAGE, VERSION, GTK_MAJOR_VERSION, GTK_MINOR_VERSION,
		 GTK_MICRO_VERSION);
	winabout=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(winabout), title);
	gtk_window_set_modal(GTK_WINDOW(winabout), TRUE);
	gtk_signal_connect(GTK_OBJECT(winabout), "delete_event",
			(GtkSignalFunc) gtk_widget_destroy, NULL);
	gtk_container_set_border_width(GTK_CONTAINER(winabout), 7);
	
	verbox=gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(winabout), verbox);
	tmpwid=gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, FALSE, FALSE, 0);
	
	text=gtk_text_new(NULL, NULL);
	gtk_text_set_editable(GTK_TEXT(text), FALSE);
	gtk_widget_set_usize(text, 520, 400);
	gtk_box_pack_start(GTK_BOX(tmpwid), text, FALSE, FALSE, 0);

	scrollbar=gtk_vscrollbar_new(GTK_TEXT(text)->vadj);
	gtk_box_pack_start(GTK_BOX(tmpwid), scrollbar, FALSE, FALSE, 0);
	
	gtk_widget_realize(text);
	gtk_text_freeze(GTK_TEXT(text));
	gtk_text_insert(GTK_TEXT(text), NULL, &text->style->black , NULL,
			abouttext, strlen(abouttext));
	gtk_text_thaw(GTK_TEXT(text));
	
	tmpwid=gtk_hseparator_new();
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, TRUE, TRUE, 0);
	
	tmpwid=gtk_button_new_with_label("Close");
	gtk_signal_connect_object(GTK_OBJECT(tmpwid), "clicked",
			(GtkSignalFunc) gtk_widget_destroy, GTK_OBJECT(winabout));
	gtk_box_pack_start(GTK_BOX(verbox), tmpwid, FALSE, FALSE, 0);
	
	gtk_widget_show_all(winabout);

}
